==> spring-boot-ext-1.2.48-sources.jar: cn/com/duibaboot/ext/autoconfigure/perftest/binaryjedis/BinaryJedisMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.perftest.binaryjedis;

import java.lang.reflect.Method;

import cn.com.duiba.boot.perftest.PerfTestContext;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.EnhancedInstance;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;
import com.alibaba.ttl.TransmittableThreadLocal;
import com.google.common.base.MoreObjects;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import redis.clients.jedis.BinaryJedis;
import redis.clients.jedis.Jedis;

/**
 * 拦截jedis操作，在方法执行前切换dbindex，执行后切换回
 */
public class BinaryJedisMethodInterceptor implements InstanceMethodsAroundInterceptor {
    private static final Integer PERF_INDEX=1;
    private final TransmittableThreadLocal<Integer> perfMode = new TransmittableThreadLocal<>();

    @Override
    public void beforeMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = MoreObjects.firstNonNull(perfMode.get(), 0);
            perfMode.set(++state);
            if (state > 1) return;
            PerfTestContext.debugInfo("BinaryJedis");
            BinaryJedis jedis = (BinaryJedis) objInst;
            jedis.select( jedis.getDB().intValue()+PERF_INDEX);
        }
    }

    @Override
    public Object afterMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = perfMode.get();
            perfMode.set(--state);
            if (state == 0) {
                BinaryJedis jedis = (BinaryJedis) objInst;
                jedis.select(jedis.getDB().intValue() - PERF_INDEX);
                perfMode.remove();
            }
        }
        return ret;
    }

    @Override
    public void handleMethodException(EnhancedInstance objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}

==> spring-boot-ext-1.2.191-sources.jar: cn/com/duibaboot/ext/autoconfigure/perftest/binaryjedis/BinaryJedisMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.perftest.binaryjedis;

import java.lang.reflect.Method;

import cn.com.duiba.boot.perftest.PerfTestContext;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;
import com.alibaba.ttl.TransmittableThreadLocal;
import com.google.common.base.MoreObjects;
import redis.clients.jedis.BinaryJedis;

/**
 * 拦截jedis操作，在方法执行前切换dbindex，执行后切换回
 */
public class BinaryJedisMethodInterceptor implements InstanceMethodsAroundInterceptor {
    private static final Integer PERF_INDEX=1;
    private final TransmittableThreadLocal<Integer> perfMode = new TransmittableThreadLocal<>();

    @Override
    public void beforeMethod(Object objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            if (method.getName().equals("publish")) {
                allArguments[0]="PerfTest".getBytes("UTF-8");
            }
            Integer state = MoreObjects.firstNonNull(perfMode.get(), 0);
            perfMode.set(++state);
            if (state > 1) return;
            PerfTestContext.debugInfo("BinaryJedis");
            BinaryJedis jedis = (BinaryJedis) objInst;
            jedis.select( jedis.getDB().intValue()+PERF_INDEX);
        }
    }

    @Override
    public Object afterMethod(Object zuperCall, Object objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = perfMode.get();
            perfMode.set(--state);
            if (state == 0) {
                BinaryJedis jedis = (BinaryJedis) objInst;
                jedis.select(jedis.getDB().intValue() - PERF_INDEX);
                perfMode.remove();
            }
        }
        return ret;
    }

    @Override
    public void handleMethodException(Object objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}
